"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.putBucketTags = void 0;
const checkBucketName_1 = require("../utils/checkBucketName");
const obj2xml_1 = require("../utils/obj2xml");
const checkBucketTag_1 = require("../utils/checkBucketTag");
/**
 * putBucketTags
 * @param {String} name - bucket name
 * @param {Object} tag -  bucket tag, eg: `{a: "1", b: "2"}`
 * @param {Object} options
 */
async function putBucketTags(name, tag, options = {}) {
    checkBucketName_1.checkBucketName(name);
    checkBucketTag_1.checkBucketTag(tag);
    const params = this._bucketRequestParams('PUT', name, 'tagging', options);
    params.successStatuses = [200];
    tag = Object.keys(tag).map(key => ({
        Key: key,
        Value: tag[key]
    }));
    const paramXMLObj = {
        Tagging: {
            TagSet: {
                Tag: tag
            }
        }
    };
    params.mime = 'xml';
    params.content = obj2xml_1.obj2xml(paramXMLObj);
    const result = await this.request(params);
    return {
        res: result.res,
        status: result.status
    };
}
exports.putBucketTags = putBucketTags;
